/*
** Generated by X-Designer
*/
#ifndef _halffont_h
#define _halffont_h

#define XD_MOTIF



extern Widget app_shell;
extern Widget drawable;

extern void create_app_shell (Display *, char *, int, char **);



#endif
